@@ -6,12 +6,9 @@ import re
 from setuptools import setup
 
 
-PACKAGES = ['distro_info_test']
-PY_MODULES = ['distro_info']
-SCRIPTS = [
-    'debian-distro-info',
-    'ubuntu-distro-info',
-]
+PACKAGES = []
+PY_MODULES = ["distro_info"]
+SCRIPTS = ["debian-distro-info", "ubuntu-distro-info"]
 
 
 def get_debian_version():
@@ -19,18 +16,18 @@ def get_debian_version():
     version = None
     changelog = "../debian/changelog"
     if os.path.exists(changelog):
-        head = open(changelog).readline()
+        head = open(changelog, "rb").readline().decode("utf-8")
         match = re.compile(r".*\((.*)\).*").match(head)
         if match:
             version = match.group(1)
     return version
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     setup(
-        name='distro-info',
+        name="distro-info",
         version=get_debian_version(),
         py_modules=PY_MODULES,
         packages=PACKAGES,
-        test_suite='distro_info_test.discover',
+        test_suite="distro_info_test",
     )
